@@ -1,4 +1,5 @@
 from abc import ABC
+from enum import Enum
 from functools import lru_cache
 from math import sqrt
 from operator import itemgetter
@@ -22,12 +23,23 @@ from wasabi import msg
 # _home = os.path.expanduser('~')
 # xdg_cache_home = os.environ.get('XDG_CACHE_HOME') or os.path.join(_home, '.cache')
 
+class TextRankAlgo(str, Enum):
+    textrank = 'textrank'
+    positionrank = 'positionrank'
+    # biasedtextrank = 'biasedtextrank'
+
 
 class TextRankSummarizerParameters(FormatterParameters):
     as_metadata: str = Field(None, description="""If defined generate the summary as a metadata of the input document,
     if not replace the text of the input document.""")
     lang: str = Field("en",
                       description="Name of the 2-letter language of the documents")
+    algo: TextRankAlgo = Field(TextRankAlgo.textrank, description="""The textgraph algorithms to use<br />
+    <li>`textrank` TextRank by [mihalcea04textrank](https://web.eecs.umich.edu/~mihalcea/papers/mihalcea.emnlp04.pdf)<br />
+    <li>`positionrank` PositionRank by [florescuc17](https://www.aclweb.org/anthology/P17-1102.pdf)<br />""")
+    # <li>`biasedtextrank` Biased TextRank by [kazemi-etal-2020-biased](https://www.aclweb.org/anthology/2020.coling-main.144.pdf)<br />""")
+    algo: TextRankAlgo = Field(TextRankAlgo.textrank,
+                               description="Name of the 2-letter language of the documents")
     num_sentences: float = Field(0.25, description="""Number of sentences of the summary:<br/>
         <li>If float in the range [0.0, 1.0], then consider num_sentences as a percentage of the original number of sentences of the document.""")
     num_phrases: int = Field(10, description="Maximum number of top-ranked phrases to use in the distance vectors.")
@@ -38,14 +50,14 @@ class TextRankSummarizerFormatter(FormatterBase, ProcessorBase, ABC):
     """
 
     # cache_dir = os.path.join(xdg_cache_home, 'trankit')
-    def _check_sentences(self, nlp, document: Document):
+    def _check_sentences(self, nlp, algo: str, document: Document):
         doc: Doc = None
         if not document.sentences:
             doc = nlp(document.text)
         else:
-            textrank = nlp.get_pipe("textrank")
+            textrank = nlp.get_pipe(algo)
             parser = nlp.get_pipe("parser")
-            with nlp.select_pipes(disable=["parser", "textrank"]):
+            with nlp.select_pipes(disable=["parser", algo]):
                 doc = nlp(document.text)
                 sent_map = RangeMap()
                 for i, s in enumerate(document.sentences):
@@ -70,8 +82,8 @@ class TextRankSummarizerFormatter(FormatterBase, ProcessorBase, ABC):
 
         params: TextRankSummarizerParameters = \
             cast(TextRankSummarizerParameters, parameters)
-        nlp = get_nlp(params.lang)
-        doc = self._check_sentences(nlp, document)
+        nlp = get_nlp(params.lang, params.algo.value)
+        doc = self._check_sentences(nlp, params.algo.value, document)
         sent_bounds = [[s.start, s.end, set([])] for s in doc.sents]
         num_sentences = int_float(params.num_sentences)
         limit_sentences = round(len(sent_bounds) * num_sentences) if isinstance(num_sentences, float) else num_sentences
@@ -153,7 +165,7 @@ MODEL_SHORTCUTS = {
 
 
 @lru_cache(maxsize=None)
-def get_nlp(lang: str, ttl_hash=None):
+def get_nlp(lang: str, algo: str, ttl_hash=None):
     del ttl_hash
     model = MODEL_SHORTCUTS.get(lang, lang)
     # model = lang
@@ -161,7 +173,7 @@ def get_nlp(lang: str, ttl_hash=None):
         nlp: Language = spacy.load(model)
     except BaseException:
         nlp = load_spacy_model(model)
-    nlp.add_pipe("textrank", last=True)
+    nlp.add_pipe(algo, last=True)
     return nlp
 
 
